@@ -1,5 +1,8 @@
 package RapidApp::Catalyst;
 
+use strict;
+use warnings;
+
 die "RapidApp::Catalyst is DEPRECATED - please use Catalyst::Plugin::RapidApp";
 
 
